@@ -5,9 +5,9 @@ use strict;
 use warnings;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2023-02-15'; # DATE
+our $DATE = '2023-02-16'; # DATE
 our $DIST = 'App-CSVUtils'; # DIST
-our $VERSION = '1.013'; # VERSION
+our $VERSION = '1.014'; # VERSION
 
 use App::CSVUtils qw(
                         gen_csv_util
@@ -18,7 +18,7 @@ gen_csv_util(
     summary => 'Output a summary row which are range notation of numbers',
     description => <<'_',
 
-You can use this to check whether integer values in a column form a contiguous
+You can use this to check whether integer values in a field form a contiguous
 range.
 
 Non-numbers will be assumed to be 0.
@@ -45,7 +45,7 @@ Example:
     quux,6
     corge,6
 
-    % csv-sum products2 --with-data-row
+    % csv-intrange products2 --with-data-row
     name,sku_number
     foo,1
     bar,2
@@ -128,7 +128,7 @@ App::CSVUtils::csv_intrange - Output a summary row which are range notation of n
 
 =head1 VERSION
 
-This document describes version 1.013 of App::CSVUtils::csv_intrange (from Perl distribution App-CSVUtils), released on 2023-02-15.
+This document describes version 1.014 of App::CSVUtils::csv_intrange (from Perl distribution App-CSVUtils), released on 2023-02-16.
 
 =head1 FUNCTIONS
 
@@ -141,7 +141,7 @@ Usage:
 
 Output a summary row which are range notation of numbers.
 
-You can use this to check whether integer values in a column form a contiguous
+You can use this to check whether integer values in a field form a contiguous
 range.
 
 Non-numbers will be assumed to be 0.
@@ -168,7 +168,7 @@ Example:
  quux,6
  corge,6
  
- % csv-sum products2 --with-data-row
+ % csv-intrange products2 --with-data-row
  name,sku_number
  foo,1
  bar,2
